4.8. umbra.components.addons.traceUi.traceUi — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.8. umbra.components.addons.traceUi.traceUi

traceUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `TraceUi` Component Interface class and others helper objects.

Others:

## 4.8.1. Module Attributes

`umbra.components.addons.traceUi.traceUi.` `LOGGER`

`umbra.components.addons.traceUi.traceUi.` `COMPONENT_UI_FILE`

## 4.8.2. Classes

class `umbra.components.addons.traceUi.traceUi.` `TraceUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  This class is the `umbra.components.addons.traceUi.traceUi` Component Interface class.

  Parameters: | parent – Object parent. ( QObject ) name – Component name. ( String ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `refreshNodes`

    This signal is emited by the `TraceUi` class when `TraceUi.model` class property model nodes needs to be refreshed. ( pyqtSignal )

  `dockArea`

    This method is the property for self.__dockArea attribute.

    Returns: | self.__dockArea. ( Integer )

  `engine`

    This method is the property for self.__engine attribute.

    Returns: | self.__engine. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( QSettings )

  `settingsSection`

    This method is the property for self.__settingsSection attribute.

    Returns: | self.__settingsSection. ( String )

  `model`

    This method is the property for self.__model attribute.

    Returns: | self.__model. ( CollectionsModel )

  `view`

    This method is the property for self.__view attribute.

    Returns: | self.__view. ( QWidget )

  `headers`

    This method is the property for self.__headers attribute.

    Returns: | self.__headers. ( OrderedDict )

  `activate`(engine)

    This method activates the Component.

    Parameters: | engine – Engine to attach the Component to. ( QObject )
    Returns: | Method success. ( Boolean )

  `deactivate`()

    This method deactivates the Component.

    Returns: | Method success. ( Boolean )

  `initializeUi`()

    This method initializes the Component ui.

    Returns: | Method success. ( Boolean )

  `uninitializeUi`()

    This method uninitializes the Component ui.

    Returns: | Method success. ( Boolean )

  `addWidget`()

    This method adds the Component Widget to the engine.

    Returns: | Method success. ( Boolean )

  `removeWidget`()

    This method removes the Component Widget from the engine.

    Returns: | Method success. ( Boolean )

  `getSelectedNodes`()

    This method returns the View selected nodes.

    Returns: | View selected nodes. ( Dictionary )

  `getSelectedModules`()

    This method returns the View selected modules.

    Returns: | View selected modules. ( List )

  `traceModules`(modules, pattern=u'.*', flags=2)

    This method traces given modules using given filter pattern.

    Parameters: | modules – Modules to trace. ( List ) pattern – Matching pattern. ( String ) flags – Matching regex flags. ( Integer )
    Returns: | Method success. ( Boolean )

  `untraceModules`(modules)

    This method untraces given modules.

    Parameters: | modules – Modules to untrace. ( List )
    Returns: | Method success. ( Boolean )

  `getModules`()

    This method sets the registered Modules.

    Returns: | Registered modules. ( List )

  `setModules`(modules=None)

    This method sets the modules Model nodes.

    Parameters: | modules – Modules to set. ( List )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »